==> haskell-validation-selective-0.2.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-LAlm9wFCZVjKjxYl0kAHbv
key:                  validation-selective-0.2.0.0-LAlm9wFCZVjKjxYl0kAHbv
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  373c0c3b7eae53e17bad857fb3970223
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-LAlm9wFCZVjKjxYl0kAHbv
depends:
    base-4.16.4.0 deepseq-1.4.6.1 selective-0.6-JsheXm3fZmzG24OJlxay1w

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validation-selective-0.2.0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-555fyDjBpuW4ySQFkbzQ9s
key:                  validation-selective-0.2.0.0-555fyDjBpuW4ySQFkbzQ9s
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  6e6ea88b46a3554a0c928b943c10f067
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-555fyDjBpuW4ySQFkbzQ9s
depends:
    base-4.16.4.0 deepseq-1.4.6.1 selective-0.6-8sRhKTeszXeLRTtXangmXg

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
